@@ -40,13 +40,12 @@ class AmocrmApiLoader:
     """
 
     def __init__(
-        self,
-        entity,
-        s3_client,
-        args_api,
-        date_modified_from=None,
-        with_offset=True,
-        batch_api=250,
+            self,
+            entity,
+            s3_client,
+            args_api,
+            date_modified_from=None,
+            batch_api=250
     ):
         """
         :param entity:   amocrm entities contacts/users/accounts e.t.c
@@ -67,7 +66,6 @@ class AmocrmApiLoader:
         self.args_api = args_api
         self.batch_api = batch_api
         self.date_modified_from = date_modified_from
-        self.with_offset = with_offset
 
         self.s3_client = s3_client
 
@@ -116,7 +114,7 @@ class AmocrmApiLoader:
             response = json.loads(self.s3_client.read_file(self.s3_client.secret_dir))
             now_str = datetime.now().strftime("%Y-%m-%d %H:%M")
             if (
-                now_str < response["expires_in_datetime"]
+                    now_str < response["expires_in_datetime"]
             ):  # check if access token is still valid
                 self.access_token = response["access_token"]
                 return
@@ -135,7 +133,7 @@ class AmocrmApiLoader:
                 raise NotImplementedError(
                     "You should pass code_auth argument to save the new refresh and access tokens "
                     " (or get and save  them the first time) "
-                ) from  exp
+                ) from exp
             response = self.__get_tokens(
                 args={"code": code_auth, "grant_type": "authorization_code"}
             )
@@ -191,10 +189,7 @@ class AmocrmApiLoader:
             self.logger.info("Extracting page №%d", cur_page)
             file_path = self.__get_file_name(cur_page, self.batch_api)
 
-            if self.with_offset == 1:
-                url = url_base.format(limit=self.batch_api, page=cur_page)
-            else:
-                url = url_base
+            url = url_base.format(limit=self.batch_api, page=cur_page)
 
             objects = requests.get(url, headers=self.get_headers(), params=params)
             self.logger.info(objects.url)
